nypoly: 'SpatialPolygons' object for New York leukemia data.

nypolyR Documentation

SpatialPolygons object for New York leukemia data.

Description

A SpatialPolygons object for the New York leukemia data in nydf. Note that the coordinates in the polygon have been projected to a different coordinate system (UTM, zone 18), but the order of the regions/polygons is the same as in nydf.

Usage

data(nypoly)

Format

A SpatialPolygonDataFrame

Bivand, R. S., Pebesma, E. J., Gomez-Rubio, V., and Pebesma, E. J. (2013). Applied Spatial Data Analysis with R, 2nd edition. New York: Springer.


smerc documentation built on Aug. 20, 2026, 9:08 a.m.