smerc: smerc

smercR Documentation

smerc

Description

*S*tatistical *ME*thods for *R*egional *C*ounts

Details

The **smerc** package implements statistical methods for analyzing the counts of areal data, with a focus on the detection of spatial clusters and clustering. The package has a heavy emphasis on spatial scan methods.

Author(s)

Maintainer: Joshua French joshua.french@ucdenver.edu (ORCID)

Authors:

Other contributors:

  • Mohammad Meysami (ORCID) [contributor]

See Also

Useful links:


smerc documentation built on Aug. 20, 2026, 9:08 a.m.