w2segments: Returns segments connecting neighbors

View source: R/smerc_cluster-plot.R

w2segmentsR Documentation

Returns segments connecting neighbors

Description

w2segments takes a binary spatial proximity matrix and associated coordinates. It returns segments connecting the neighbors for plotting purposes

Usage

w2segments(w, coords)

smerc documentation built on Aug. 20, 2026, 9:08 a.m.